@@ -21,6 +21,7 @@ __all__ = [
     "angle_between",
     "Counter",
     "clockwise",
+    "get_current_user",
     "get_file_size",
     "is_coplanar",
     "make_cylinder_from_points",
@@ -1999,7 +2000,7 @@ def easy_plotly(
             os.makedirs(dirpath)
         pio.write_image(fig, save_filename, width=1600, height=800)
         if "\\" not in save_filename:
-            output_file = r"C:\Users\{}\Downloads\{}.png".format(os.getlogin(), filename)
+            output_file = pathlib.Path(f"C:/ADA/temp/{filename}.png")
             if os.path.isfile(output_file) is True:
                 shutil.move(output_file, dirpath + "\\" + filename + ".png")
             else:
@@ -2011,6 +2012,16 @@ def easy_plotly(
         fig.show(renderer=renderer)
 
 
+def get_current_user():
+    """
+
+    :return: Name of current user
+    """
+    import getpass
+
+    return getpass.getuser()
+
+
 def get_list_of_files(dir_name, file_ext=None, strict=False):
     """
     Get a list of file and sub directories for a given directory
@@ -2802,3 +2813,41 @@ def split_beam(bm, fraction):
     """
     raise NotImplementedError()
     # nmid = bm.n1.p + bm.xvec * bm.length * fraction
+
+
+def are_plates_touching(pl1, pl2, tol=1e-3):
+    """
+    Check if two plates are within tolerance of eachother.
+
+    This uses the OCC shape representation of the plate.
+
+    :param pl1:
+    :param pl2:
+    :param tol:
+    :return:
+    """
+    dss = compute_minimal_distance_between_shapes(pl1.solid, pl2.solid)
+    if dss.Value() <= tol:
+        return dss
+    else:
+        return None
+
+
+def compute_minimal_distance_between_shapes(shp1, shp2):
+    """
+    compute the minimal distance between 2 shapes
+
+    :rtype: OCC.Core.BRepExtrema.BRepExtrema_DistShapeShape
+    """
+    from OCC.Core.BRepExtrema import BRepExtrema_DistShapeShape
+
+    dss = BRepExtrema_DistShapeShape()
+    dss.LoadS1(shp1)
+    dss.LoadS2(shp2)
+    dss.Perform()
+
+    assert dss.IsDone()
+
+    logging.info("Minimal distance between shapes: ", dss.Value())
+
+    return dss
